@@ -104,7 +104,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "./stylecssparser.yy"
+#line 1 "../../../lib/srchilite/stylecssparser.yy"
 
 /*
  * Copyright (C) 1999-2007 Lorenzo Bettini <http://www.lorenzobettini.it>
@@ -194,7 +194,7 @@ static string errorBuffer;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 70 "./stylecssparser.yy"
+#line 70 "../../../lib/srchilite/stylecssparser.yy"
 {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
@@ -1116,7 +1116,7 @@ yydestruct (yymsg, yytype, yyvaluep)
   switch (yytype)
     {
       case 9: /* "KEY" */
-#line 83 "./stylecssparser.yy"
+#line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1124,7 +1124,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1125 "stylecssparser.cc"
 	break;
       case 10: /* "COLOR" */
-#line 83 "./stylecssparser.yy"
+#line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1132,7 +1132,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1133 "stylecssparser.cc"
 	break;
       case 11: /* "BG_COLOR" */
-#line 83 "./stylecssparser.yy"
+#line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1140,7 +1140,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1141 "stylecssparser.cc"
 	break;
       case 12: /* "STRINGDEF" */
-#line 83 "./stylecssparser.yy"
+#line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
@@ -1148,7 +1148,7 @@ yydestruct (yymsg, yytype, yyvaluep)
 #line 1149 "stylecssparser.cc"
 	break;
       case 22: /* "keylist" */
-#line 83 "./stylecssparser.yy"
+#line 83 "../../../lib/srchilite/stylecssparser.yy"
 	{
 	if ((yyvaluep->keylist))
 	  delete (yyvaluep->keylist);
@@ -1462,12 +1462,12 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 90 "./stylecssparser.yy"
+#line 90 "../../../lib/srchilite/stylecssparser.yy"
     { /* allow empty files */ }
     break;
 
   case 7:
-#line 102 "./stylecssparser.yy"
+#line 102 "../../../lib/srchilite/stylecssparser.yy"
     {
                //printSequence( $1 ) ;
                //printMessage_noln( ": " ) ;
@@ -1478,7 +1478,7 @@ yyreduce:
     break;
 
   case 8:
-#line 110 "./stylecssparser.yy"
+#line 110 "../../../lib/srchilite/stylecssparser.yy"
     {
                KeyType key;
                KeyList *keylist = (yyvsp[(1) - (4)].keylist);
@@ -1513,7 +1513,7 @@ yyreduce:
     break;
 
   case 9:
-#line 144 "./stylecssparser.yy"
+#line 144 "../../../lib/srchilite/stylecssparser.yy"
     {
               (yyvsp[(1) - (3)].keylist)->push_back(*(yyvsp[(3) - (3)].string));
               (yyval.keylist) = (yyvsp[(1) - (3)].keylist);
@@ -1522,7 +1522,7 @@ yyreduce:
     break;
 
   case 10:
-#line 150 "./stylecssparser.yy"
+#line 150 "../../../lib/srchilite/stylecssparser.yy"
     {
               (yyval.keylist) = new KeyList;
               (yyval.keylist)->push_back(*(yyvsp[(1) - (1)].string));
@@ -1531,12 +1531,12 @@ yyreduce:
     break;
 
   case 11:
-#line 157 "./stylecssparser.yy"
+#line 157 "../../../lib/srchilite/stylecssparser.yy"
     {}
     break;
 
   case 16:
-#line 167 "./stylecssparser.yy"
+#line 167 "../../../lib/srchilite/stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1544,7 +1544,7 @@ yyreduce:
     break;
 
   case 17:
-#line 172 "./stylecssparser.yy"
+#line 172 "../../../lib/srchilite/stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1552,7 +1552,7 @@ yyreduce:
     break;
 
   case 18:
-#line 179 "./stylecssparser.yy"
+#line 179 "../../../lib/srchilite/stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1560,7 +1560,7 @@ yyreduce:
     break;
 
   case 19:
-#line 184 "./stylecssparser.yy"
+#line 184 "../../../lib/srchilite/stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1568,32 +1568,32 @@ yyreduce:
     break;
 
   case 20:
-#line 190 "./stylecssparser.yy"
+#line 190 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISBOLD); }
     break;
 
   case 21:
-#line 191 "./stylecssparser.yy"
+#line 191 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISITALIC); }
     break;
 
   case 22:
-#line 192 "./stylecssparser.yy"
+#line 192 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISUNDERLINE); }
     break;
 
   case 23:
-#line 193 "./stylecssparser.yy"
+#line 193 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISFIXED); }
     break;
 
   case 24:
-#line 194 "./stylecssparser.yy"
+#line 194 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISNOTFIXED); }
     break;
 
   case 25:
-#line 195 "./stylecssparser.yy"
+#line 195 "../../../lib/srchilite/stylecssparser.yy"
     { currentStyleConstants->push_back(ISNOREF); }
     break;
 
@@ -1813,7 +1813,7 @@ yyreturn:
 }
 
 
-#line 198 "./stylecssparser.yy"
+#line 198 "../../../lib/srchilite/stylecssparser.yy"
 
 
 // string current_file; defined in styleparser
