@@ -1,9 +1,10 @@
 #include <iostream>
 
 #include "asserttestexit.h"
-#include "srcuntabifier.h"
+#include "srchilite/srcuntabifier.h"
 
 using namespace std;
+using namespace srchilite;
 
 int main() {
     Untabifier untabifier(4);
@@ -23,14 +24,14 @@ int main() {
     preformat = untabifier2.preformat(orig);
 
     cout << "preformat: " << preformat << endl;
-    
+
     //assertEquals("   with        tabs", preformat);
 
     preformat = untabifier2.preformat("\n");
     preformat = untabifier2.preformat("\tsecond line");
 
     cout << "preformat: " << preformat << endl;
-    
+
     assertEquals("    second line", preformat);
 
     cout << "test_untabifier: SUCCESS" << endl;
